===============================
seaflux
===============================


.. image:: https://img.shields.io/travis/luke-gregor/SeaFlux.svg
        :target: https://travis-ci.org/luke-gregor/SeaFlux
.. image:: https://badgen.net/pypi/v/seaflux
        :target: https://pypi.org/project/seaflux
.. image:: https://img.shields.io/badge/License-GPLv3-blue.svg
        :target: https://www.gnu.org/licenses/gpl-3.0


Calculate sea-air fluxes
